@@ -1,7 +1,5 @@
 package WWW::Map::UK::Streetmap;
 
-package Streetmap;
-
 use 5.006;
 use strict;
 use warnings;
@@ -11,7 +9,7 @@ use LWP::UserAgent;
 
 use vars qw ($VERSION);
 
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 =head1 NAME
 
@@ -35,8 +33,7 @@ www.streetmap.co.uk
   my %os_location = $streetmap->get_location(os_x => '525688',
                                              os_y => '181069');
 
-  # get location by WGS84 latitude and longitude (World Geodetic
-  # System)
+  # get location by WGS84 latitude and longitude (World Geodetic  # System)
 
   my %wgs_location = $streetmap->get_location(wgs_lat  => '51.514572',
                                               wgs_long => '-0.190067');
@@ -356,8 +353,6 @@ LWP::UserAgent
 
 =head1 TODO
 
-Proper tests.
-
 Caching. The module will be able to cache locations its seen before to
 a text file, or possibly a database (mysql initially, I expect). This
 will be vastly superior for relatively busy applications. We may even
